@@ -5,11 +5,11 @@
 #'
 #' @param object A S3 object of class \code{krr} created by \code{\link{fastkrr}}.
 #' @param newdata New design matrix or data frame containing new observations
-#'                for which predictions are to be made.
+#'                for which predictions are to be made. If \code{newdata} is missing, the function returns fitted values.
 #' @param ... Additional arguments (currently ignored).
 #'
 #'
-#' @return A numeric vector of predicted values corresponding to \code{newdata}.
+#' @return A numeric vector of predicted values corresponding to \code{newdata} or fitted values.
 #'
 #' @seealso \code{\link{fastkrr}}, \code{\link{make_kernel}}
 #'
@@ -31,10 +31,14 @@
 #' new_y = as.vector(sin(2*pi*rowMeans(new_x)^3) + rnorm(new_n, 0, 0.1))
 #'
 #' pred = predict(model, new_x)
-#' crossprod(pred, new_y) / new_n
+#' crossprod(pred - new_y) / new_n
+#'
+#' predict(model) == attributes(model)$fitted.values
 #' @importFrom stats predict
 #' @export
 predict.krr = function(object, newdata, ...){
+  if(missing(newdata)) return(attributes(object)$fitted.values)
+
   if(attributes(object)$opt == "rff"){
     x_new = newdata
     W = attributes(object)$W
@@ -333,7 +337,7 @@ fastkrr = function(x, y,
     rslt = rff(x, y, rand_set$W, rand_set$b, lambda = lambda, n_threads = n_threads)
 
     attr(result_values, "coefficients") = rslt$coefficients
-    attr(result_values, "fitted.values") = rslt$coefficients
+    attr(result_values, "fitted.values") = as.vector(rslt$coefficients)
     attr(result_values, "opt") = opt
     attr(result_values, "kernel") = kernel
     attr(result_values, "x") = x
